'use strict';

var framework = require('@sapphire/framework');
var v10 = require('discord-api-types/v10');
var functions_cjs = require('./functions.cjs');
var types_cjs = require('./types.cjs');

var __defProp = Object.defineProperty;
var __name = (target, value) => __defProp(target, "name", { value, configurable: true });
var RegisterSubcommandsHooks = {
  subcommands: /* @__PURE__ */ __name((piece, context) => {
    const subcommands = functions_cjs.subCommandsRegistry.get(piece.name);
    if (!subcommands) {
      framework.container.logger.error(
        `[Subcommands-Plugin]: An attempt was made to obtain the subcommands for the parent command ${piece.name} but no command was registered for it.`
      );
      return;
    }
    for (const { slashCommand, commandPiece } of subcommands.values()) {
      if (slashCommand && context) {
        context.options.push(slashCommand);
      }
      const subcommand = {
        name: slashCommand?.name ?? commandPiece?.name ?? "",
        type: "method",
        chatInputRun: commandPiece.chatInputRun ? async (i, c) => {
          const result = await piece.preconditions.chatInputRun(i, piece);
          if (result.isErr()) {
            return piece.container.client.emit(
              types_cjs.SubcommandsAdvancedEvents.ChatInputSubcommandDenied,
              result.err().unwrapOr(new framework.UserError({ context: c, identifier: "SubcommandDenied", message: "Unknown error" })),
              {
                command: piece,
                interaction: i,
                subcommand,
                matchedSubcommandMapping: commandPiece.name,
                context: c
              }
            );
          }
          return commandPiece.chatInputRun(i, c);
        } : void 0,
        messageRun: commandPiece.messageRun ? async (m, a, c) => {
          const result = await piece.preconditions.messageRun(m, piece);
          if (result.isErr()) {
            return piece.container.client.emit(
              types_cjs.SubcommandsAdvancedEvents.MessageSubcommandDenied,
              result.err().unwrapOr(new framework.UserError({ context: c, identifier: "SubcommandDenied", message: "Unknown error" })),
              {
                command: piece,
                message: m,
                subcommand,
                matchedSubcommandMapping: commandPiece.name,
                context: c
              }
            );
          }
          return commandPiece.messageRun(m, a, c);
        } : void 0
      };
      piece.parsedSubcommandMappings.push(subcommand);
    }
  }, "subcommands"),
  groups: /* @__PURE__ */ __name((piece, context) => {
    const subcommandsGroups = functions_cjs.subCommandsGroupRegistry.get(piece.name);
    if (!subcommandsGroups) {
      framework.container.logger.error(
        `[Subcommands-Group-Plugin]: An attempt was made to obtain the subcommand groups for the parent command ${piece.name} but no command was registered for it.`
      );
      return;
    }
    for (const [name, commands] of subcommandsGroups) {
      for (const { slashCommand, commandPiece } of [...commands.values()]) {
        const groupMapping = piece.parsedSubcommandMappings.find(
          ({ name: x, type }) => x === name && type === "group"
        );
        const subcommand = {
          name: slashCommand?.name ?? commandPiece?.name ?? "",
          type: "method",
          chatInputRun: commandPiece.chatInputRun ? async (i, c) => {
            const result = await piece.preconditions.chatInputRun(i, piece);
            if (result.isErr()) {
              return piece.container.client.emit(
                types_cjs.SubcommandsAdvancedEvents.ChatInputSubcommandDenied,
                result.err().unwrapOr(new framework.UserError({ context: c, identifier: "SubcommandDenied", message: "Unknown error" })),
                {
                  command: piece,
                  interaction: i,
                  subcommand,
                  matchedSubcommandMapping: commandPiece.name,
                  context: c
                }
              );
            }
            return commandPiece.chatInputRun(i, c);
          } : void 0,
          messageRun: commandPiece.messageRun ? async (m, a, c) => {
            const result = await piece.preconditions.messageRun(m, piece);
            if (result.isErr()) {
              return piece.container.client.emit(
                types_cjs.SubcommandsAdvancedEvents.MessageSubcommandDenied,
                result.err().unwrapOr(new framework.UserError({ context: c, identifier: "SubcommandDenied", message: "Unknown error" })),
                {
                  command: piece,
                  message: m,
                  subcommand,
                  matchedSubcommandMapping: commandPiece.name,
                  context: c
                }
              );
            }
            return commandPiece.messageRun(m, a, c);
          } : void 0
        };
        if (groupMapping) groupMapping.entries.push(subcommand);
        else {
          piece.parsedSubcommandMappings.push({
            name,
            type: "group",
            entries: [subcommand]
          });
        }
      }
      if (context) {
        for (const option of context.options) {
          const data = option.toJSON();
          if (data.name === name && data.type === v10.ApplicationCommandOptionType.SubcommandGroup) {
            option.options?.push(
              ...[...commands.values()].filter(({ slashCommand }) => slashCommand).map(({ slashCommand }) => slashCommand)
            );
          }
        }
      }
    }
  }, "groups")
};

exports.RegisterSubcommandsHooks = RegisterSubcommandsHooks;
//# sourceMappingURL=out.js.map
//# sourceMappingURL=const.cjs.map