'use strict';

var framework = require('@sapphire/framework');
var discord_js = require('discord.js');
var builders = require('@discordjs/builders');

var __defProp = Object.defineProperty;
var __name = (target, value) => __defProp(target, "name", { value, configurable: true });
var subCommandsRegistry = new discord_js.Collection();
var subCommandsGroupRegistry = new discord_js.Collection();
var isCommandOptionsUpdated = /* @__PURE__ */ __name((c1, c2) => JSON.stringify(c1.toJSON()) !== JSON.stringify(c2.toJSON()), "isCommandOptionsUpdated");
var parseSlashSubcommand = /* @__PURE__ */ __name((subcommand) => subcommand ? typeof subcommand === "function" ? subcommand(new builders.SlashCommandSubcommandBuilder(), framework.container) : subcommand : void 0, "parseSlashSubcommand");
var analizeSubCommandParsed = /* @__PURE__ */ __name((piece, parentCommandName, subcommand) => {
  const subcommandParsed = parseSlashSubcommand(subcommand);
  const subcommandsRegistry = subCommandsRegistry.get(parentCommandName);
  if (!subcommandsRegistry) {
    subCommandsRegistry.set(
      parentCommandName,
      new discord_js.Collection().set(subcommandParsed?.name ?? piece.name, {
        slashCommand: subcommandParsed,
        commandPiece: piece
      })
    );
    framework.container.logger.debug(
      `[Subcommands-Plugin]: The parent command "${parentCommandName}" has been registered and the subcommand "${subcommandParsed?.name ?? piece.name}" has been registered.`
    );
    return piece;
  }
  const subcommandName = subcommandParsed?.name ?? piece.name;
  const command = subcommandsRegistry.get(subcommandName);
  if (!command) {
    subcommandsRegistry.set(subcommandName, {
      slashCommand: subcommandParsed,
      commandPiece: piece
    });
    framework.container.logger.debug(
      `[Subcommands-Plugin]: The subcommand "${subcommandName}" has been registered in the parent command "${parentCommandName}".`
    );
    return piece;
  }
  const commandsCompare = subcommandParsed && command.slashCommand && isCommandOptionsUpdated(command.slashCommand, subcommandParsed);
  if (commandsCompare) {
    subcommandsRegistry.delete(subcommandName);
    subcommandsRegistry.set(subcommandName, {
      slashCommand: subcommandParsed,
      commandPiece: piece
    });
    framework.container.logger.debug(
      `[Subcommands-Plugin]: The subcommand "${subcommandName}" has been updated in the parent command ${parentCommandName} ${commandsCompare ? "with new options" : "without new options"}.`
    );
  }
  const parentCommand = framework.container.stores.get("commands").get(parentCommandName);
  if (parentCommand) {
    if (!parentCommand?.parsedSubcommandMappings) {
      framework.container.logger.error(
        `[Subcommands-Plugin]: The parent command ${parentCommandName} possibly does not extend the plugin Subcommand class because the "parsedSubcommandMappings" property was not found in the parent command required for the subcommand ${subcommandName}.`
      );
      return piece;
    }
    if (commandsCompare) void parentCommand.reload();
    const subcommand2 = parentCommand.parsedSubcommandMappings.find(
      (s) => s.name === subcommandName && s.type === "method"
    );
    if (subcommand2) {
      if (piece.chatInputRun) subcommand2.chatInputRun = (i, c) => piece.chatInputRun(i, c);
      if (piece.messageRun) subcommand2.messageRun = (m, a, c) => piece.messageRun(m, a, c);
    }
  } else {
    framework.container.logger.warn(
      `[Subcommands-Plugin]: Could not get information from the parent command ${parentCommandName} for the subcommand ${subcommandName}.`
    );
  }
  return piece;
}, "analizeSubCommandParsed");
var analizeSubcommandGroupParsed = /* @__PURE__ */ __name((piece, parentCommandName, groupName, subcommand) => {
  const subcommandParsed = parseSlashSubcommand(subcommand);
  const subcommandsGroup = subCommandsGroupRegistry.get(parentCommandName);
  if (!subcommandsGroup) {
    subCommandsGroupRegistry.set(
      parentCommandName,
      new discord_js.Collection().set(
        groupName,
        new discord_js.Collection().set(subcommandParsed?.name ?? piece.name, {
          slashCommand: subcommandParsed,
          commandPiece: piece
        })
      )
    );
    framework.container.logger.debug(
      `[Subcommands-Group-Plugin]: The parent command "${parentCommandName}" has been registered and the group "${groupName}" has been created with the registered "${subcommandParsed?.name ?? piece.name}" command.`
    );
    return piece;
  }
  const group = subcommandsGroup.get(groupName);
  if (!group) {
    subcommandsGroup.set(
      groupName,
      new discord_js.Collection().set(subcommandParsed?.name ?? piece.name, {
        slashCommand: subcommandParsed,
        commandPiece: piece
      })
    );
    framework.container.logger.debug(
      `[Subcommands-Group-Plugin]: The group "${groupName}" has been registered with the command ${subcommandParsed?.name ?? piece.name} registered in the parent command "${parentCommandName}".`
    );
    return piece;
  }
  const subcommandName = subcommandParsed?.name ?? piece.name;
  const commandGroup = group.get(subcommandName);
  if (!commandGroup) {
    group.set(subcommandName, {
      slashCommand: subcommandParsed,
      commandPiece: piece
    });
    framework.container.logger.debug(
      `[Subcommands-Group-Plugin]: The command "${subcommandName}" has been registered in the group "${groupName}" of the parent command "${parentCommandName}".`
    );
    return piece;
  }
  const commandsGroupCompare = subcommandParsed && commandGroup.slashCommand && isCommandOptionsUpdated(commandGroup.slashCommand, subcommandParsed);
  group.delete(subcommandName);
  group.set(subcommandName, {
    slashCommand: subcommandParsed,
    commandPiece: piece
  });
  framework.container.logger.debug(
    `[Subcommands-Group-Plugin]: The command ${subcommandName} has been updated in the group "${groupName}" of the parent command "${parentCommandName}" ${commandsGroupCompare ? "with new options" : "without new options"}.`
  );
  const parentCommand = framework.container.stores.get("commands").get(parentCommandName);
  if (parentCommand) {
    if (!parentCommand?.parsedSubcommandMappings) {
      framework.container.logger.error(
        `[Subcommands-Group-Plugin]: The parent command ${parentCommandName} possibly does not extend the plugin Subcommand class because the "parsedSubcommandMappings" property was not found in the parent command required for the subcommand ${subcommandName} of the subcommand group ${groupName}.`
      );
      return piece;
    }
    if (commandsGroupCompare) void parentCommand.reload();
    const subcommandGroup = parentCommand.parsedSubcommandMappings.find(
      (s) => s.name === groupName && s.type === "group"
    );
    if (subcommandGroup) {
      const subcommand2 = subcommandGroup.entries.find((s) => s.name === subcommandName && s.type === "method");
      if (subcommand2) {
        if (piece.chatInputRun) subcommand2.chatInputRun = (i, c) => piece.chatInputRun(i, c);
        if (piece.messageRun) subcommand2.messageRun = (m, a, c) => piece.messageRun(m, a, c);
      }
    }
  } else {
    framework.container.logger.warn(
      `[Subcommands-Group-Plugin]: Could not get information from the parent command ${parentCommandName} for the subcommand ${subcommandName} of the subcommand group ${groupName}.`
    );
  }
  return piece;
}, "analizeSubcommandGroupParsed");

exports.analizeSubCommandParsed = analizeSubCommandParsed;
exports.analizeSubcommandGroupParsed = analizeSubcommandGroupParsed;
exports.isCommandOptionsUpdated = isCommandOptionsUpdated;
exports.parseSlashSubcommand = parseSlashSubcommand;
exports.subCommandsGroupRegistry = subCommandsGroupRegistry;
exports.subCommandsRegistry = subCommandsRegistry;
//# sourceMappingURL=out.js.map
//# sourceMappingURL=functions.cjs.map